@@ -13,7 +13,7 @@ class ADObject(ADBase):
     _optional_attributes = None
     _py_ad_object_mappings = {}
     
-    def __set_adsi_obj(self, distinguished_name):
+    def __set_adsi_obj(self):
         """Internal method that creates the connection to the backend ADSI object."""
     
         if self.default_username and self.default_password:
@@ -82,7 +82,7 @@ class ADObject(ADBase):
                             self.default_ldap_server,
                             self.default_ldap_port
             )
-            self.__set_adsi_obj(distinguished_name)
+            self.__set_adsi_obj()
         else:
             raise Exception("Either a distinguished name or a COM object must be provided to create an ADObject")
 
@@ -390,6 +390,10 @@ class ADObject(ADBase):
         # http://www.microsoft.com/technet/scriptcenter/topics/win2003/lastlogon.mspx
         # kudos to http://docs.activestate.com/activepython/2.6/pywin32/html/com/help/active_directory.html
         return pyadutils.convert_datetime(self.get_attribute('pwdLastSet', False))
+        
+    def get_last_login(self):
+        """Returns datetime object of when user last login on the connected domain controller."""
+        return pyadutils.convert_datetime(self.get_attribute('lastLogonTimestamp', False))
 
     def get_uSNChanged(self):
         """Returns uSNChanged as a single integer from the current domain controller"""
