@@ -47,9 +47,9 @@ class ADQuery(ADBase):
         assert type in ("LDAP", "GC")
         if not base_dn:
             if type == "LDAP": 
-                base_dn = self.default_domain
+                base_dn = self._safe_default_domain
             if type == "GC": 
-                base_dn = default_forest
+                base_dn = self._safe_default_forest
         query = "SELECT %s FROM '%s'" % (','.join(attributes),
                 pyadutils.generate_ads_path(base_dn, type,
                         self.default_ldap_server, self.default_ldap_port))
